==> scopeagent-0.3.2-py3-none-any.whl: scopeagent/instrumentation/client_kombu.py <==
import logging

import opentracing
import wrapt

import scopeagent
from ..tracer import tags


logger = logging.getLogger(__name__)


def publish_wrapper(wrapped, instance, args, kwargs):
    logger.debug("intercepting request: instance=%s args=%s kwargs=%s", instance, args, kwargs)
    headers = kwargs.get('headers', {})
    with scopeagent.global_agent.tracer.start_active_span(
            operation_name="Publish message",
            tags={
                tags.SPAN_KIND: tags.SPAN_KIND_PUBLISH,
            }) as scope:
        scopeagent.global_agent.tracer.inject(scope.span.context, format=opentracing.Format.HTTP_HEADERS,
                                         carrier=headers)
        kwargs['headers'] = headers
        return wrapped(*args, **kwargs)


def receive_wrapper(wrapped, instance, args, kwargs):
    logger.debug("intercepting request: instance=%s args=%s kwargs=%s", instance, args, kwargs)
    message = args[0] if len(args) >= 1 else kwargs.get('message')
    headers = message.headers
    try:
        context = scopeagent.global_agent.tracer.extract(format=opentracing.Format.HTTP_HEADERS, carrier=headers)
    except opentracing.SpanContextCorruptedException:
        context = None

    with scopeagent.global_agent.tracer.start_active_span(
            child_of=context,
            operation_name="Receive message",
            tags={
                tags.SPAN_KIND: tags.SPAN_KIND_RECEIVE,
            }):
        return wrapped(*args, **kwargs)


def patch():
    try:
        logger.debug("patching module=kombu.messaging name=Producer.publish")
        wrapt.wrap_function_wrapper('kombu.messaging', 'Producer.publish', publish_wrapper)
        logger.debug("patching module=kombu.messaging name=Consumer._receive_callback")
        wrapt.wrap_function_wrapper('kombu.messaging', 'Consumer._receive_callback', receive_wrapper)
    except ImportError:
        logger.debug("module not found module=kombu.messaging")

==> scopeagent-0.3.5-py3-none-any.whl: scopeagent/instrumentation/client_kombu.py <==
import logging

import opentracing
import wrapt

import scopeagent
from ..tracer import tags


logger = logging.getLogger(__name__)


def publish_wrapper(wrapped, instance, args, kwargs):
    logger.debug("intercepting request: instance=%s args=%s kwargs=%s", instance, args, kwargs)
    headers = kwargs.get('headers', {})
    with opentracing.tracer.start_active_span(
            operation_name="Publish message",
            tags={
                tags.SPAN_KIND: tags.SPAN_KIND_PUBLISH,
            }) as scope:
        opentracing.tracer.inject(scope.span.context, format=opentracing.Format.HTTP_HEADERS,
                                         carrier=headers)
        kwargs['headers'] = headers
        return wrapped(*args, **kwargs)


def receive_wrapper(wrapped, instance, args, kwargs):
    logger.debug("intercepting request: instance=%s args=%s kwargs=%s", instance, args, kwargs)
    message = args[0] if len(args) >= 1 else kwargs.get('message')
    headers = message.headers
    try:
        context = opentracing.tracer.extract(format=opentracing.Format.HTTP_HEADERS, carrier=headers)
    except opentracing.SpanContextCorruptedException:
        context = None

    with opentracing.tracer.start_active_span(
            child_of=context,
            operation_name="Receive message",
            tags={
                tags.SPAN_KIND: tags.SPAN_KIND_RECEIVE,
            }):
        return wrapped(*args, **kwargs)


def patch():
    try:
        logger.debug("patching module=kombu.messaging name=Producer.publish")
        wrapt.wrap_function_wrapper('kombu.messaging', 'Producer.publish', publish_wrapper)
        logger.debug("patching module=kombu.messaging name=Consumer._receive_callback")
        wrapt.wrap_function_wrapper('kombu.messaging', 'Consumer._receive_callback', receive_wrapper)
    except ImportError:
        logger.debug("module not found module=kombu.messaging")
